@@ -1,3 +1,25 @@
+/*
+
+Copyright (C) 2006, 2007 John W. Eaton
+
+This file is part of Octave.
+
+Octave is free software; you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
+
+Octave is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
+
+*/
+
 /* 
    A C-program for MT19937, with initialization improved 2002/2/10.
    Coded by Takuji Nishimura and Makoto Matsumoto.
@@ -125,7 +147,6 @@
 #include <config.h>
 #endif
 
-#include <math.h>
 #include <stdio.h>
 #include <time.h>
 
@@ -133,6 +154,7 @@
 #include <sys/time.h>
 #endif
 
+#include "lo-math.h"
 #include "randmtzig.h"
    
 /* FIXME may want to suppress X86 if sizeof(long)>4 */
@@ -356,6 +378,8 @@ randi54 (void)
 #endif
 }
 
+#if 0
+// FIXME -- this doesn't seem to be used anywhere; should it be removed?
 static uint64_t 
 randi64 (void)
 {
@@ -371,7 +395,9 @@ randi64 (void)
   return (((uint64_t)hi<<32)|lo);
 #endif
 }
+#endif
 
+#ifdef ALLBITS
 /* generates a random number on (0,1)-real-interval */
 static double
 randu32 (void)
@@ -379,30 +405,27 @@ randu32 (void)
   return ((double)randi32() + 0.5) * (1.0/4294967296.0); 
   /* divided by 2^32 */
 }
-
+#else
 /* generates a random number on (0,1) with 53-bit resolution */
 static double
 randu53 (void) 
 { 
   const uint32_t a=randi32()>>5;
   const uint32_t b=randi32()>>6; 
-  return(a*67108864.0+b+0.4) * (1.0/9007199254740992.0);
+  return (a*67108864.0+b+0.4) * (1.0/9007199254740992.0);
 } 
+#endif
 
 /* Determine mantissa for uniform doubles */
+double
+oct_randu (void)
+{
 #ifdef ALLBITS
-double
-oct_randu (void)
-{
-  return randu32();
-}
+  return randu32 ();
 #else
-double
-oct_randu (void)
-{
-  return randu53();
-}
+  return randu53 ();
 #endif
+}
 
 /* ===== Ziggurat normal and exponential generators ===== */
 #ifdef ALLBITS
