@@ -1,25 +1,25 @@
-## Copyright (C) 1996, 1998 Auburn University.  All rights reserved.
+## Copyright (C) 1996, 1998, 2004, 2005, 2006, 2007
+##               Auburn University. All rights reserved.
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301 USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{outsys} =} ss (@var{a}, @var{b}, @var{c}, @var{d}, @var{tsam}, @var{n}, @var{nz}, @var{stname}, @var{inname}, @var{outname}, @var{outlist})
-## Create system structure from state-space data.   May be continous,
+## Create system structure from state-space data.   May be continuous,
 ## discrete, or mixed (sampled data)
 ##
 ## @strong{Inputs}
@@ -71,7 +71,7 @@
 ## If @var{tsam} is greater than 0, @math{outlist = 1:@code{rows}(@var{c})}.
 ## @end table
 ##
-## Unlike states, discrete/continous outputs may appear in any order.
+## Unlike states, discrete/continuous outputs may appear in any order.
 ##
 ## @code{sys2ss} returns a vector @var{yd} where
 ## @var{yd}(@var{outlist}) = 1; all other entries of @var{yd} are 0.
@@ -144,7 +144,8 @@
 ## octave:1> a = [1 2 3; 4 5 6; 7 8 10];
 ## octave:2> b = [0 0 ; 0 1 ; 1 0];
 ## octave:3> c = eye (3);
-## octave:4> sys = ss (a, b, c, [], 0, 3, 0, @{"volts", "amps", "joules"@});
+## octave:4> sys = ss (a, b, c, [], 0, 3, 0, ...
+## >                   @{"volts", "amps", "joules"@});
 ## octave:5> sysout(sys);
 ## Input(s)
 ##         1: u_1
@@ -190,60 +191,68 @@
 function retsys = ss (a, b, c, d, tsam, n, nz, stname, inname, outname, outlist)
 
   ## Test for correct number of inputs
-  if ((nargin < 3) | (nargin > 11))
+  if (nargin < 3 || nargin > 11)
     print_usage ();
   endif
 
   ## verify A, B, C, D arguments
   ## If D is not specified, set it to a zero matrix of appriate dimension.
-  if (nargin == 3)          d = zeros(rows(c) , columns(b));
-  elseif (isempty(d))       d = zeros(rows(c) , columns(b));      endif
+  if (nargin == 3)
+    d = zeros (rows (c), columns (b));
+  elseif (isempty (d))
+    d = zeros (rows (c), columns (b));
+  endif
 
   ## Check the dimensions
-  [na,m,p] = abcddim(a,b,c,d);
+  [na, m, p] = abcddim (a, b, c, d);
 
   ## If dimensions are wrong, exit function
   if (m == -1)
-    error("a(%dx%d), b(%dx%d), c(%dx%d), d(%dx%d); incompatible", ...
-      rows(a), columns(a), rows(b), columns(b), rows(c), columns(c), ...
-      rows(d), columns(d));
+    error ("a(%dx%d), b(%dx%d), c(%dx%d), d(%dx%d); incompatible",
+	   rows (a), columns (a), rows (b), columns (b),
+	   rows (c), columns (c), rows (d), columns (d));
   endif
 
   ## check for tsam input
-  if(nargin < 5) tsam = 0;
-  elseif( !( is_sample(tsam) | (tsam == 0) ) )
-    error("tsam must be a nonnegative real scalar");
+  if (nargin < 5)
+    tsam = 0;
+  elseif (! (is_sample (tsam) || tsam == 0))
+    error ("tsam must be a nonnegative real scalar");
   endif
 
   ## check for continuous states
-  if( (nargin < 6) & (tsam == 0) )               n = na;
-  elseif(nargin < 6)                             n = 0;
-  elseif((!ismatrix(n)) | ischar(n))
-    error("Parameter n is not a numerical value.");
-  elseif( (!isscalar(n)) | (n < 0 ) | (n != round(n)) )
-    if(isscalar(n))     error("invalid value of n=%d,%e",n,n);
-    else                 error("invalid value of n=(%dx%d)", ...
-                           rows(n), columns(n));                endif
+  if (nargin < 6 && tsam == 0)
+    n = na;
+  elseif (nargin < 6)
+    n = 0;
+  elseif (! ismatrix (n) || ischar (n))
+    error ("Parameter n is not a numerical value.");
+  elseif (! isscalar(n) || n < 0 || n != round (n))
+    if (isscalar (n))
+      error ("invalid value of n=%d,%e", n, n);
+    else
+      error ("invalid value of n=(%dx%d)", rows (n), columns (n));
+    endif
   endif
 
   ## check for num discrete states
-  if( (nargin < 7) & (tsam == 0))               nz = 0;
-  elseif(nargin < 7)                            nz = na - n;
-  elseif((!ismatrix(nz)) | ischar(nz))
-    error("Parameter nz is not a numerical value.");
-  elseif( (!isscalar(nz)) | (nz < 0 ) | (nz != round(nz)) )
-    if(isscalar(nz))
-      error(["invalid value of nz=",num2str(nz)]);
+  if (nargin < 7 && tsam == 0)
+    nz = 0;
+  elseif (nargin < 7)
+    nz = na - n;
+  elseif (! ismatrix(nz) || ischar (nz))
+    error ("Parameter nz is not a numerical value.");
+  elseif (! isscalar(nz) || nz < 0 || nz != round(nz))
+    if (isscalar (nz))
+      error ("invalid value of nz=%d", nz);
     else
-      error(["invalid value of nz=(",num2str(rows(nz)),"x", ...
-        num2str(columns(nz)),")"]);
+      error ("invalid value of nz=(%d,%d)", rows (nz), columns (nz));
     endif
   endif
 
   ## check for total number of states
-  if( (n + nz) != na )
-    error(["invalid: a is ",num2str(na),"x",num2str(na),", n=", ...
-        num2str(n),", nz=",num2str(nz)]);
+  if ((n + nz) != na)
+    error ("invalid: a is %dx%d, n=%d, nz=%d", na, na, n, nz);
   endif
 
   ## construct system with default names
@@ -255,7 +264,7 @@ function retsys = ss (a, b, c, d, tsam, n, nz, stname, inname, outname, outlist)
   retsys.n = n;
   retsys.nz = nz;
   retsys.tsam = tsam;
-  retsys.yd = zeros(1,p);     # default value entered below
+  retsys.yd = zeros (1, p);     # default value entered below
 
   ## Set the system vector:  active = 2(ss), updated = [0 0 1];
   retsys.sys = [2, 0, 0, 1];
@@ -265,26 +274,32 @@ function retsys = ss (a, b, c, d, tsam, n, nz, stname, inname, outname, outlist)
   retsys.outname = __sysdefioname__ (p, "y");
 
   ## check for state names
-  if(nargin >= 8)
-    if(!isempty(stname)) retsys = syssetsignals(retsys,"st",stname); endif
+  if (nargin >= 8)
+    if (! isempty (stname))
+      retsys = syssetsignals (retsys, "st", stname);
+    endif
   endif
 
   ## check for input names
-  if(nargin >= 9)
-    if(!isempty(inname)) retsys = syssetsignals(retsys,"in",inname); endif
+  if (nargin >= 9)
+    if (! isempty (inname))
+      retsys = syssetsignals (retsys, "in", inname);
+    endif
   endif
 
   ## check for output names
-  if(nargin >= 10)
-    if(!isempty(outname)) retsys = syssetsignals(retsys,"out",outname); endif
+  if (nargin >= 10)
+    if (! isempty (outname))
+      retsys = syssetsignals (retsys, "out", outname);
+    endif
   endif
 
   ## set up yd
-  if(nargin < 11)
-    retsys = syssetsignals(retsys,"yd",ones(1,p)*(tsam > 0));
+  if (nargin < 11)
+    retsys = syssetsignals (retsys, "yd", ones(1,p)*(tsam > 0));
   else
-    if(!isempty(outlist))
-      retsys = syssetsignals(retsys,"yd",ones(size(outlist)),outlist);
+    if (! isempty (outlist))
+      retsys = syssetsignals (retsys, "yd", ones (size (outlist)), outlist);
     endif
   endif
 
