@@ -1,11 +1,12 @@
-## Copyright (C) 1995, 1996  Kurt Hornik
+## Copyright (C) 1995, 1996, 1999, 2000, 2002, 2004, 2005, 2006, 2007
+##               Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +14,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} diff (@var{x}, @var{k}, @var{dim})
@@ -98,13 +98,13 @@ function x = diff (x, k, dim)
       n = sz (dim);
       idx1 = cell ();
       for i = 1:nd
-	idx1 {i} = 1:sz(i);
+	idx1{i} = 1:sz(i);
       endfor
       idx2 = idx1;
       for i = 1 : k;
-	idx1 {dim} = 2 : (n - i + 1);	
-	idx2 {dim} = 1 : (n - i);	
-	x = x (idx1 {:}) - x (idx2 {:});
+	idx1{dim} = 2 : (n - i + 1);	
+	idx2{dim} = 1 : (n - i);	
+	x = x(idx1{:}) - x(idx2{:});
       endfor
     endif
   else
@@ -113,17 +113,17 @@ function x = diff (x, k, dim)
     else
       idx1 = cell ();
       for i = 1:nd
-	idx1 {i} = 1:sz(i);
+	idx1{i} = 1:sz(i);
       endfor
       idx2 = idx1;
       while (k)
 	n = sz (dim);
 	for i = 1 : min (k, n - 1)
-	  idx1 {dim} = 2 : (n - i + 1);	
-	  idx2 {dim} = 1 : (n - i);	
-	  x = x (idx1 {:}) - x (idx2 {:});
+	  idx1{dim} = 2 : (n - i + 1);	
+	  idx2{dim} = 1 : (n - i);	
+	  x = x(idx1{:}) - x(idx2{:});
 	endfor
-	idx1 {dim} = idx2 {dim} = 1;
+	idx1{dim} = idx2{dim} = 1;
 	k = k - min (k, n - 1);
 	dim = dim + 1;
       endwhile
