@@ -21,8 +21,8 @@
 ## @deftypefn {Function File} {} image (@var{img})
 ## @deftypefnx {Function File} {} image (@var{x}, @var{y}, @var{img})
 ## Display a matrix as a color image.  The elements of @var{x} are indices
-## into the current colormap and should have values between 1 and the
-## length of the colormap.
+## into the current colormap, and the colormap will be scaled so that the
+## extremes of @var{x} are mapped to the extremes of teh colormap.
 ##
 ## It first tries to use @code{gnuplot}, then @code{display} from 
 ## @code{ImageMagick}, then @code{xv}, and then @code{xloadimage}.
@@ -39,35 +39,43 @@
 ## Created: July 1994
 ## Adapted-By: jwe
 
-function h = image (x, y, img)
+function retval = image (varargin)
 
-  ## Deprecated zoom.  Remove this hunk of code if old zoom argument
-  ## is outmoded.
-  if ((nargin == 2 && isscalar (y)) || nargin == 4)
-    warning ("image: zoom argument ignored -- use GUI features");
-  endif
-  if (nargin == 4)
-    nargin = 3;
-  endif
-  if (nargin == 2 && isscalar (y))
-    nargin = 1;
-  endif
+  [ax, varargin, nargin] = __plt_get_axis_arg__ ("image", varargin{:});
 
-  if (nargin == 0)
-    ## Load Bobbie Jo Richardson (Born 3/16/94)
+  firstnonnumeric = Inf;
+  for i = 1 : nargin
+    if (! isnumeric (varargin{i}))
+      firstnonnumeric = i;
+      break;
+    endif
+  endfor
+
+  if (nargin == 0 || firstnonnumeric == 1)
     img = loadimage ("default.img");
     x = y = [];
-  elseif (nargin == 1)
-    img = x;
+  elseif (nargin == 1 || firstnonnumeric == 2)
+    img = varargin{1};
     x = y = [];
-  elseif (nargin == 2 || nargin > 3)
+  elseif (nargin == 2 || firstnonnumeric == 3)
     print_usage ();
+  else
+    x = varargin{1};
+    y = varargin{2};
+    img = varargin{3};
+    firstnonnumeric = 4;
   endif
 
-  tmp = __img__ (x, y, img);
+  oldax = gca ();
+  unwind_protect
+    axes (ax);
+    h = __img__ (x, y, img, varargin {firstnonnumeric:end});
+  unwind_protect_cleanup
+    axes (oldax);
+  end_unwind_protect
 
   if (nargout > 0)
-    h = tmp;
+    retval = h;
   endif
 
 endfunction
