@@ -20,9 +20,9 @@
 
 ## Author: jwe
 
-function __go_draw_axes__ (h, plot_stream, enhanced)
+function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 
-  if (nargin == 3)
+  if (nargin == 4)
 
     axis_obj = get (h);
 
@@ -87,7 +87,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
     if (! isempty (axis_obj.xlabel))
       t = get (axis_obj.xlabel);
       angle = t.rotation;
-      colorspec = get_text_colorspec (axis_obj.xcolor);
+      colorspec = get_text_colorspec (axis_obj.xcolor, mono);
       if (isempty (t.string))
 	fprintf (plot_stream, "unset xlabel;\n");
 	fprintf (plot_stream, "unset x2label;\n");
@@ -123,7 +123,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
     if (! isempty (axis_obj.ylabel))
       t = get (axis_obj.ylabel);
       angle = t.rotation;
-      colorspec = get_text_colorspec (axis_obj.ycolor);
+      colorspec = get_text_colorspec (axis_obj.ycolor, mono);
       if (isempty (t.string))
 	fprintf (plot_stream, "unset ylabel;\n");
 	fprintf (plot_stream, "unset y2label;\n");
@@ -157,7 +157,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
     if (! isempty (axis_obj.zlabel))
       t = get (axis_obj.zlabel);
       angle = t.rotation;
-      colorspec = get_text_colorspec (axis_obj.zcolor);
+      colorspec = get_text_colorspec (axis_obj.zcolor, mono);
       if (isempty (t.string))
 	fputs (plot_stream, "unset zlabel;\n");
       else
@@ -194,25 +194,31 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
       yaxisloc_using = "y1";
     endif
 
+    have_grid = false;
+
     if (strcmpi (axis_obj.xgrid, "on"))
+      have_grid = true;
       fprintf (plot_stream, "set grid %stics;\n", xaxisloc);
     else
       fprintf (plot_stream, "set grid no%stics;\n", xaxisloc);
     endif
 
     if (strcmpi (axis_obj.ygrid, "on"))
+      have_grid = true;
       fprintf (plot_stream, "set grid %stics;\n", yaxisloc);
     else
       fprintf (plot_stream, "set grid no%stics;\n", yaxisloc);
     endif
 
     if (strcmpi (axis_obj.zgrid, "on"))
+      have_grid = true;
       fputs (plot_stream, "set grid ztics;\n");
     else
       fputs (plot_stream, "set grid noztics;\n");
     endif
 
     if (strcmpi (axis_obj.xminorgrid, "on"))
+      have_grid = true;
       fprintf (plot_stream, "set m%stics 5;\n", xaxisloc);
       fprintf (plot_stream, "set grid m%stics;\n", xaxisloc);
     else
@@ -220,6 +226,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
     endif
 
     if (strcmpi (axis_obj.yminorgrid, "on"))
+      have_grid = true;
       fprintf (plot_stream, "set m%stics 5;\n", yaxisloc);
       fprintf (plot_stream, "set grid m%stics;\n", yaxisloc);
     else
@@ -227,13 +234,21 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
     endif
 
     if (strcmpi (axis_obj.zminorgrid, "on"))
+      have_grid = true;
       fputs (plot_stream, "set mztics 5;\n");
       fputs (plot_stream, "set grid mztics;\n");
     else
       fputs (plot_stream, "set grid nomztics;\n");
     endif
 
-    do_tics (axis_obj, plot_stream, ymirror);
+    ## Unless we force the grid to the front, tics may appear below
+    ## plotted objects.
+    fputs (plot_stream, "set grid front;\n");
+    if (! have_grid)
+      fputs (plot_stream, "unset grid;\n");
+    endif
+
+    do_tics (axis_obj, plot_stream, ymirror, mono);
 
     xlogscale = strcmpi (axis_obj.xscale, "log");
     if (xlogscale)
@@ -268,6 +283,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
     data = cell ();
     is_image_data = [];
     hidden_removal = NaN;
+    view_map = false;
 
     xlim = axis_obj.xlim;
     ylim = axis_obj.ylim;
@@ -305,6 +321,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 
 	  if (use_gnuplot_for_images)
 
+	    fputs (plot_stream, "set border front;\n");
 	    data_idx++;
 	    is_image_data(data_idx) = true;
 	    parametric(data_idx) = false;
@@ -360,7 +377,8 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 	    tmp = undo_string_escapes (__maybe_munge_text__ (enhanced, obj, "keylabel", have_newer_gnuplot));
 	    titlespec{data_idx} = strcat ("title \"", tmp, "\"");
 	  endif
-	  [style, typ, with] = do_linestyle_command (obj, data_idx, plot_stream);
+	  [style, typ, with] = do_linestyle_command (obj, data_idx,
+						     mono, plot_stream);
 	  usingclause{data_idx} = "";
 	  if (have_newer_gnuplot || isnan (typ))
 	    withclause{data_idx} = sprintf ("with %s linestyle %d",
@@ -509,8 +527,8 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 	       usingclause{data_idx} = "";
                if (isfield (obj, "facecolor"))
 		 if ((strncmp (obj.facecolor, "flat", 4)
-		     || strncmp (obj.facecolor, "interp", 6)) &&
-		     isfield (obj, "cdata"))
+		     || strncmp (obj.facecolor, "interp", 6))
+		     && isfield (obj, "cdata"))
 		   if (ndims (obj.cdata) == 2
 		       && (size (obj.cdata, 2) == nc
 			   && (size (obj.cdata, 1) == 1
@@ -551,9 +569,14 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
                endif
 
 	       if (have_newer_gnuplot)
-		 withclause{data_idx} ...
-		     = sprintf ("with filledcurve lc rgb \"#%02x%02x%02x\"",
-				round (255*color));
+		 if (mono)
+		   colorspec = "";
+		 else
+		   colorspec = sprintf ("lc rgb \"#%02x%02x%02x\"",
+					round (255*color));
+		 endif
+		 withclause{data_idx} = sprintf ("with filledcurve %s",
+						 colorspec);
 	       else
 		 if (isequal (color, [0,0,0]))
 		   typ = -1;
@@ -602,8 +625,8 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 
              if (isfield (obj, "edgecolor"))
 	       if ((strncmp (obj.edgecolor, "flat", 4)
-		    || strncmp (obj.edgecolor, "interp", 6)) &&
-		   isfield (obj, "cdata"))
+		    || strncmp (obj.edgecolor, "interp", 6))
+		   && isfield (obj, "cdata"))
 		 if (ndims (obj.cdata) == 2
 		     && (size (obj.cdata, 2) == nc
 			 && (size (obj.cdata, 1) == 1
@@ -730,9 +753,14 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 	     endif
 
 	     if (have_newer_gnuplot)
-	       withclause{data_idx} ...
-		   = sprintf ("with %s %s %s lc rgb \"#%02x%02x%02x\"",
-			      style, pt, ps, round (255*color));
+	       if (mono)
+		 colorspec = "";
+	       else
+		 colorspec = sprintf ("lc rgb \"#%02x%02x%02x\"",
+				      round (255*color));
+	       endif
+	       withclause{data_idx} = sprintf ("with %s %s %s %s",
+					       style, pt, ps, colorspec);
 	     else
 	       if (isequal (color, [0,0,0]))
 		 typ = -1;
@@ -778,6 +806,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 
 	case "surface"
 	  nd = 3;
+	  view_map = true;
           if (! (strncmp (obj.edgecolor, "none", 4)
 		 && strncmp (obj.facecolor, "none", 4)))
 	    data_idx++;
@@ -785,7 +814,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 	    parametric(data_idx) = false;
 	    have_cdata(data_idx) = true;
 	    [style, typ, with] = do_linestyle_command (obj, data_idx,
-						       plot_stream);
+						       mono, plot_stream);
 	    if (isempty (obj.keylabel))
 	      titlespec{data_idx} = "title \"\"";
 	    else
@@ -818,7 +847,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
                 err = true;
 	      endif
 	    elseif (ismatrix (xdat) && ismatrix (ydat) && ismatrix (zdat))
-	      if (! (size_equal (xdat, ydat) && size_equal (xdat, zdat)))
+	      if (! size_equal (xdat, ydat, zdat))
                 err = true;
 	      endif
 	    else
@@ -899,9 +928,15 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 			 data_idx, interp_str, dord);
 
 		if (have_newer_gnuplot)
+		  if (mono)
+		    colorspec = "";
+		  else
+		    colorspec = sprintf ("linecolor rgb \"#%02x%02x%02x\"",
+					 round (255*edgecol));
+		  endif
                   fprintf (plot_stream,
-                           "set style line %d linecolor rgb \"#%02x%02x%02x\" lw %f;\n",
-                           data_idx, round (255*edgecol), obj.linewidth);
+                           "set style line %d %s lw %f;\n",
+                           data_idx, colorspec, obj.linewidth);
 		else
 		  if (isequal (edgecol, [0,0,0]))
 		    typ = -1;
@@ -950,19 +985,19 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
           endif
 	  
 	  if (isnumeric (color))
-	    colorspec = get_text_colorspec (color);
+	    colorspec = get_text_colorspec (color, mono);
 	  endif
 
 	  if (nd == 3)
 	    fprintf (plot_stream,
-		     "set label \"%s\" at %s %.15g,%.15g,%.15g %s %s rotate by %f %s;\n",
+		     "set label \"%s\" at %s %.15g,%.15g,%.15g %s rotate by %f %s front %s;\n",
 		     undo_string_escapes (label), units, lpos(1),
-		     lpos(2), lpos(3), fontspec, halign, angle, colorspec);
+		     lpos(2), lpos(3), halign, angle, fontspec, colorspec);
 	  else
  	    fprintf (plot_stream,
- 		     "set label \"%s\" at %s %.15g,%.15g %s %s rotate by %f %s;\n",
+ 		     "set label \"%s\" at %s %.15g,%.15g %s rotate by %f %s front %s;\n",
  		     undo_string_escapes (label), units,
- 		     lpos(1), lpos(2), fontspec, halign, angle, colorspec);
+ 		     lpos(1), lpos(2), halign, angle, fontspec, colorspec);
 	  endif
 
 	otherwise
@@ -1153,7 +1188,11 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 	  rot_z += 360;
 	endwhile
  	fputs (plot_stream, "set ticslevel 0;\n");
-	fprintf (plot_stream, "set view %.15g, %.15g;\n", rot_x, rot_z);
+	if (view_map && rot_x == 0 && rot_z == 0)
+	  fputs (plot_stream, "set view map;\n");
+	else
+	  fprintf (plot_stream, "set view %.15g, %.15g;\n", rot_x, rot_z);
+	endif
       endif
       fprintf (plot_stream, "%s \"-\" %s %s %s \\\n", plot_cmd,
 	       usingclause{1}, titlespec{1}, withclause{1});
@@ -1174,6 +1213,11 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
       fputs (plot_stream, "plot \"-\";\nInf Inf\ne\n");
     endif
 
+    ## Needed to allow mouse rotation with pcolor
+    if (view_map)
+      fputs (plot_stream, "unset view;\n");
+    endif
+
     fflush (plot_stream);
 
   else
@@ -1182,7 +1226,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced)
 
 endfunction
 
-function [style, typ, with] = do_linestyle_command (obj, idx, plot_stream)
+function [style, typ, with] = do_linestyle_command (obj, idx, mono, plot_stream)
 
   persistent have_newer_gnuplot ...
     = compare_versions (__gnuplot_version__ (), "4.0", ">");
@@ -1200,8 +1244,10 @@ function [style, typ, with] = do_linestyle_command (obj, idx, plot_stream)
     color = obj.color;
     if (isnumeric (color))
       if (have_newer_gnuplot)
-	fprintf (plot_stream, " linecolor rgb \"#%02x%02x%02x\"",
-		 round (255*color));
+	if (! mono)
+	  fprintf (plot_stream, " linecolor rgb \"#%02x%02x%02x\"",
+		   round (255*color));
+	endif
       else
 	if (isequal (color, [0,0,0]))
 	  typ = -1;
@@ -1398,35 +1444,36 @@ function __gnuplot_write_data__ (plot_stream, data, nd, parametric, cdata)
 
 endfunction
 
-function do_tics (obj, plot_stream, ymirror)
+function do_tics (obj, plot_stream, ymirror, mono)
   if (strcmpi (obj.xaxislocation, "top"))
     do_tics_1 (obj.xtickmode, obj.xtick, obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x2", plot_stream, true);
+	       obj.xcolor, "x2", plot_stream, true, mono);
     do_tics_1 ("manual", [], obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x", plot_stream, true);
+	       obj.xcolor, "x", plot_stream, true, mono);
   else
     do_tics_1 (obj.xtickmode, obj.xtick, obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x", plot_stream, true);
+	       obj.xcolor, "x", plot_stream, true, mono);
     do_tics_1 ("manual", [], obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x2", plot_stream, true);
+	       obj.xcolor, "x2", plot_stream, true, mono);
   endif
   if (strcmpi (obj.yaxislocation, "right"))
     do_tics_1 (obj.ytickmode, obj.ytick, obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y2", plot_stream, ymirror);
+	       obj.ycolor, "y2", plot_stream, ymirror, mono);
     do_tics_1 ("manual", [], obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y", plot_stream, ymirror);
+	       obj.ycolor, "y", plot_stream, ymirror, mono);
   else
     do_tics_1 (obj.ytickmode, obj.ytick, obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y", plot_stream, ymirror);
+	       obj.ycolor, "y", plot_stream, ymirror, mono);
     do_tics_1 ("manual", [], obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y2", plot_stream, ymirror);
+	       obj.ycolor, "y2", plot_stream, ymirror, mono);
   endif
   do_tics_1 (obj.ztickmode, obj.ztick, obj.zticklabelmode, obj.zticklabel,
-	     obj.zcolor, "z", plot_stream, true);
+	     obj.zcolor, "z", plot_stream, true, mono);
 endfunction
 
-function do_tics_1 (ticmode, tics, labelmode, labels, color, ax, plot_stream, mirror)
-  colorspec = get_text_colorspec (color);
+function do_tics_1 (ticmode, tics, labelmode, labels, color, ax,
+		    plot_stream, mirror, mono)
+  colorspec = get_text_colorspec (color, mono);
   if (strcmpi (ticmode, "manual"))
     if (isempty (tics))
       fprintf (plot_stream, "unset %stics;\n", ax);
@@ -1478,13 +1525,17 @@ function do_tics_1 (ticmode, tics, labelmode, labels, color, ax, plot_stream, mi
   endif
 endfunction
 
-function colorspec = get_text_colorspec (color)
+function colorspec = get_text_colorspec (color, mono)
   persistent have_newer_gnuplot ...
       = compare_versions (__gnuplot_version__ (), "4.0", ">");
 
   if (have_newer_gnuplot)
-    colorspec = sprintf ("textcolor rgb \"#%02x%02x%02x\"",
-			 round (255*color));
+    if (mono)
+      colorspec = "";
+    else
+      colorspec = sprintf ("textcolor rgb \"#%02x%02x%02x\"",
+			   round (255*color));
+    endif
   else
     if (isequal (color, [0,0,0]))
       typ = -1;
