@@ -1,12 +1,14 @@
 /*
 
-Copyright (C) 2004 David Bateman
-Copyright (C) 1998-2004 Andy Adler
+Copyright (C) 2004, 2005, 2006, 2007 David Bateman
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Andy Adler
+
+This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -14,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -73,7 +74,7 @@ is forced back to a full matrix is resulting matrix is sparse\n\
 Create a sparse matrix given integer index vectors @var{i} and @var{j},\n\
 a 1-by-@code{nnz} vector of real of complex values @var{sv}, overall\n\
 dimensions @var{m} and @var{n} of the sparse matrix.  The argument\n\
-@code{nzmax} is ignored but accepted for compatability with @sc{Matlab}.\n\
+@code{nzmax} is ignored but accepted for compatibility with @sc{Matlab}.\n\
 \n\
 @strong{Note}: if multiple values are specified with the same\n\
 @var{i}, @var{j} indices, the corresponding values in @var{s} will\n\
@@ -105,13 +106,11 @@ to have a common size.\n\
 @end deftypefn")
 {
    octave_value retval;
-   bool mutate = false;
 
    // WARNING: This function should always use constructions like
    //   retval = new octave_sparse_matrix (sm);
    // To avoid calling the maybe_mutate function. This is the only
-   // function that should not call maybe_mutate, or at least only
-   // in very particular cases.
+   // function that should not call maybe_mutate
 
    int nargin= args.length();
    if (nargin < 1 || (nargin == 4 && !args(3).is_string ()) || nargin > 6) 
@@ -133,11 +132,7 @@ to have a common size.\n\
        use_bool = args(0).is_bool_type ();
      }
 
-   if (nargin == 2 && ! args(0).is_scalar_type() && args(1).is_scalar_type())
-       mutate = (args(1).double_value() != 0.);
-
-   if (nargin == 1 || (nargin == 2 && ! args(0).is_scalar_type() && 
-		       args(1).is_scalar_type()))
+   if (nargin == 1)
      {
        octave_value arg = args (0);
 
@@ -354,10 +349,6 @@ to have a common size.\n\
 	 }
      }
 
-   // Only called in very particular cases, not the default case
-   if (mutate)
-     retval.maybe_mutate ();
-
    return retval;
 }
 
