@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+              2002, 2003, 2004, 2005, 2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -126,7 +126,7 @@ static bool verbose_flag = false;
 static const char *usage_string = 
   "octave [-?HVdfhiqvx] [--debug] [--echo-commands] [--eval CODE]\n\
        [--exec-path path] [--help] [--image-path path] [--info-file file]\n\
-       [--info-program prog] [--interactive] [--no-history] [--no-init-file]\n\
+       [--info-program prog] [--interactive] [--line-editing] [--no-history] [--no-init-file]\n\
        [--no-line-editing] [--no-site-file] [--no-init-path] [-p path]\n\
        [--path path] [--silent] [--traditional] [--verbose] [--version] [file]";
 
@@ -154,6 +154,7 @@ static bool persist = false;
 #define NO_INITIAL_PATH_OPTION 9
 #define PERSIST_OPTION 10
 #define TRADITIONAL_OPTION 11
+#define LINE_EDITING_OPTION 12
 long_options long_opts[] =
   {
     { "debug",            prog_args::no_arg,       0, 'd' },
@@ -166,6 +167,7 @@ long_options long_opts[] =
     { "info-file",        prog_args::required_arg, 0, INFO_FILE_OPTION },
     { "info-program",     prog_args::required_arg, 0, INFO_PROG_OPTION },
     { "interactive",      prog_args::no_arg,       0, 'i' },
+    { "line-editing",     prog_args::no_arg,       0, LINE_EDITING_OPTION },
     { "no-history",       prog_args::no_arg,       0, 'H' },
     { "no-init-file",     prog_args::no_arg,       0, NO_INIT_FILE_OPTION },
     { "no-line-editing",  prog_args::no_arg,       0, NO_LINE_EDITING_OPTION },
@@ -225,6 +227,7 @@ initialize_pathsearch (void)
 DEFUN (__version_info__, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {retval =} __version_info__ (@var{name}, @var{version}, @var{release}, @var{date})\n\
+Undocumented internal function.\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -363,6 +366,18 @@ execute_eval_option_code (const std::string& code)
 {
   unwind_protect::begin_frame ("execute_eval_option_code");
 
+  octave_save_signal_mask ();
+
+  can_interrupt = true;
+
+  octave_signal_hook = octave_signal_handler;
+  octave_interrupt_hook = unwind_protect::run_all;
+  octave_bad_alloc_hook = unwind_protect::run_all;
+
+  octave_catch_interrupts ();
+
+  octave_initialized = true;
+
   unwind_protect_bool (interactive);
 
   interactive = false;
@@ -373,6 +388,11 @@ execute_eval_option_code (const std::string& code)
     {
       eval_string (code, false, parse_status, 0);
     }
+  catch (octave_interrupt_exception)
+    {
+      recover_from_exception ();
+      octave_stdout << "\n";
+    }
   catch (std::bad_alloc)
     {
       std::cerr << "error: memory exhausted or requested size too large for range of Octave's index type -- eval failed"
@@ -389,6 +409,18 @@ execute_command_line_file (const std::string& fname)
 {
   unwind_protect::begin_frame ("execute_command_line_file");
 
+  octave_save_signal_mask ();
+
+  can_interrupt = true;
+
+  octave_signal_hook = octave_signal_handler;
+  octave_interrupt_hook = unwind_protect::run_all;
+  octave_bad_alloc_hook = unwind_protect::run_all;
+
+  octave_catch_interrupts ();
+
+  octave_initialized = true;
+
   unwind_protect_bool (interactive);
   unwind_protect_bool (reading_script_file);
   unwind_protect_bool (input_from_command_line_file);
@@ -419,6 +451,11 @@ execute_command_line_file (const std::string& fname)
     {
       parse_and_execute (fname, false, "octave");
     }
+  catch (octave_interrupt_exception)
+    {
+      recover_from_exception ();
+      octave_stdout << "\n";
+    }
   catch (std::bad_alloc)
     {
       std::cerr << "error: memory exhausted or requested size too large for range of Octave's index type -- execution of "
@@ -448,6 +485,7 @@ Options:\n\
   --info-file FILE        Use top-level info file FILE.\n\
   --info-program PROGRAM  Use PROGRAM for reading info files.\n\
   --interactive, -i       Force interactive behavior.\n\
+  --line-editing          Force readline use for command-line editing.\n\
   --no-history, -H        Don't save commands to the history list\n\
   --no-init-file          Don't read the ~/.octaverc or .octaverc files.\n\
   --no-line-editing       Don't use readline for command-line editing.\n\
@@ -571,6 +609,8 @@ octave_main (int argc, char **argv, int embedded)
 
   prog_args args (argc, argv, short_opts, long_opts);
 
+  bool forced_line_editing = false;
+
   int optc;
   while ((optc = args.getopt ()) != EOF)
     {
@@ -653,6 +693,10 @@ octave_main (int argc, char **argv, int embedded)
 	    bind_internal_variable ("info_program", args.optarg ());
 	  break;
 
+        case LINE_EDITING_OPTION:
+          forced_line_editing = true;
+          break;
+
 	case NO_INIT_FILE_OPTION:
 	  read_init_files = false;
 	  break;
@@ -721,7 +765,7 @@ octave_main (int argc, char **argv, int embedded)
   interactive = (! embedded
 		 && isatty (fileno (stdin)) && isatty (fileno (stdout)));
 
-  if (! interactive)
+  if (! interactive && ! forced_line_editing)
     line_editing = false;
 
   // If there is an extra argument, see if it names a file to read.
